@@ -1,5 +1,5 @@
 """AI providers for commit message generation and grouping."""
 
-from .unified import UnifiedAIProvider
+from .simple_unified import UnifiedAIProvider
 
 __all__ = ['UnifiedAIProvider']
\ No newline at end of file
